pub struct BarcodeScanner { /* private fields */ }Expand description
A barcode scanner.
Implementations
Sourceimpl BarcodeScanner
impl BarcodeScanner
Sourcepub fn open(path: impl AsRef<Path>) -> Result<Self, Error>
pub fn open(path: impl AsRef<Path>) -> Result<Self, Error>
Create a barcode scanner and grab the device by a device path
Example
let mut scanner = BarcodeScanner::open("/dev/input/event18")?;Examples found in repository?
examples/scan-barcodes.rs (line 12)
3fn do_main() -> Result<(), ()> {
4 let args: Vec<_> = std::env::args().collect();
5 if args.len() != 2 {
6 let prog_name = args[0].rsplit_once('/').map(|(_parent, name)| name).unwrap_or(&args[0]);
7 eprintln!("Usage: {prog_name} DEVICE_PATH");
8 return Err(())
9 }
10
11 let device_path = &args[1];
12 let mut scanner = BarcodeScanner::open(device_path)
13 .map_err(|e| eprintln!("{e}"))?;
14
15 println!("Ready to scan barcodes");
16 loop {
17 let barcode = scanner.read().map_err(|e| println!("Failed to read barcode: {e}"))?;
18 println!("{barcode}");
19 }
20}Sourcepub fn open_by_physical_path(
physical_path: impl AsRef<str>,
) -> Result<Option<Self>, Error>
pub fn open_by_physical_path( physical_path: impl AsRef<str>, ) -> Result<Option<Self>, Error>
Create a barcode scanner and grab the device by a physical device path
Example
let device_path = "usb-0000:00:14.0-3/input0";
let mut scanner = BarcodeScanner::open_by_physical_path(device_path)
.map_err(|e| eprintln!("{}", e))?
.ok_or_else(|| eprintln!("No such device: {device_path}"))?;Sourcepub fn read(&mut self) -> Result<String, Error>
pub fn read(&mut self) -> Result<String, Error>
Read a barcode from the device.
Blocks until an entire barcode has been read.
Example
let barcode = scanner.read()?;
println!("Barcode: {barcode}");Examples found in repository?
examples/scan-barcodes.rs (line 17)
3fn do_main() -> Result<(), ()> {
4 let args: Vec<_> = std::env::args().collect();
5 if args.len() != 2 {
6 let prog_name = args[0].rsplit_once('/').map(|(_parent, name)| name).unwrap_or(&args[0]);
7 eprintln!("Usage: {prog_name} DEVICE_PATH");
8 return Err(())
9 }
10
11 let device_path = &args[1];
12 let mut scanner = BarcodeScanner::open(device_path)
13 .map_err(|e| eprintln!("{e}"))?;
14
15 println!("Ready to scan barcodes");
16 loop {
17 let barcode = scanner.read().map_err(|e| println!("Failed to read barcode: {e}"))?;
18 println!("{barcode}");
19 }
20}Auto Trait Implementations
impl Freeze for BarcodeScanner
impl RefUnwindSafe for BarcodeScanner
impl Send for BarcodeScanner
impl Sync for BarcodeScanner
impl Unpin for BarcodeScanner
impl UnwindSafe for BarcodeScanner